# Guanciale -- Carbonara Project

Grab informations needed by Carbonara from executables and disassemblers databases

## Install
```bash
$ sudo apt install radare2 python python-pip
$ pip install -r requirements.txt
$ python setup.py install
```


